@@ -1,15 +1,16 @@
 package App::JESP;
-$App::JESP::VERSION = '0.012';
+$App::JESP::VERSION = '0.013';
 use Moose;
 
 use App::JESP::Plan;
+use App::JESP::Colorizer;
 
 use Class::Load;
 use DBI;
 use DBIx::Simple;
-use Log::Any qw/$log/;
-
 use File::Spec;
+use IO::Interactive;
+use Log::Any qw/$log/;
 
 # Settings
 ## DB Connection attrbutes.
@@ -43,6 +44,9 @@ has 'meta_patches' => ( is => 'ro', isa => 'ArrayRef[HashRef]',
 has 'plan' => ( is => 'ro', isa => 'App::JESP::Plan', lazy_build => 1);
 has 'driver' => ( is => 'ro', isa => 'App::JESP::Driver', lazy_build => 1 );
 
+has 'interactive' => ( is => 'ro' , isa => 'Bool' , lazy_build => 1 );
+has 'colorizer' => ( is => 'ro', isa => 'App::JESP::Colorizer', lazy_build => 1 );
+
 sub _build_driver{
     my ($self) = @_;
     return $self->driver_class()->new({ jesp => $self });
@@ -85,6 +89,16 @@ sub _build_meta_patches{
     ];
 }
 
+sub _build_interactive{
+    my ($self) = @_;
+    return IO::Interactive::is_interactive();
+}
+
+sub _build_colorizer{
+    my ($self) = @_;
+    return App::JESP::Colorizer->new({ jesp => $self });
+}
+
 sub install{
     my ($self) = @_;
 
@@ -212,12 +226,12 @@ sub deploy{
         if( my $err = $@ ){
             $log->error("Got error $err. ROLLING BACK");
             $db->rollback();
-            die "ERROR APPLYING PATCH ".$patch->id().": $err. ABORTING\n";
+            die "ERROR APPLYING PATCH ".$patch->id().": $err. ".$self->colorizer()->colored("ABORTING", "bold red")."\n";
         };
-        $log->info("Patch '".$patch->id()."' applied successfully");
+        $log->info($self->colorizer()->colored("Patch '".$patch->id()."' applied successfully", "green"));
         $applied++;
     }
-    $log->info("DONE Deploying DB Patches");
+    $log->info($self->colorizer()->colored("DONE Deploying DB Patches", "green"));
     return $applied;
 }
 
