@@ -1,9 +1,11 @@
 package App::JESP::Cmd::Command::status;
-$App::JESP::Cmd::Command::status::VERSION = '0.012';
+$App::JESP::Cmd::Command::status::VERSION = '0.013';
 use base qw/App::JESP::Cmd::CommandJESP/;
 use strict; use warnings;
 use Log::Any qw/$log/;
 
+use utf8;
+
 =head1 NAME
 
 App::JESP::Cmd::Command::status - Shows the status of patches
@@ -34,18 +36,22 @@ sub abstract { "Show the status of the plan VS the DB" }
 sub description { "Show the status of the patches in the plan versus the patches recorded in the DB" }
 sub execute {
     my ($self, $opts, $args) = @_;
+
+    binmode STDOUT , ':utf8';
+
+    my $colorizer = $self->jesp()->colorizer();
     my $status = $self->jesp->status( $opts );
     foreach my $patch ( @{$status->{plan_patches} }){
-        print "Patch '".$patch->id()."'";
+        print "Patch '".$patch->id()."'\n";
         if( $patch->applied_datetime() ){
-            print " Applied on ".$patch->applied_datetime();
+            print " ".$colorizer->colored('✔︎', "bold green")." - Applied on ".$patch->applied_datetime();
         }else{
-            print " - not applied yet - ";
+            print " ".$colorizer->colored('⚠', "bold yellow").' - Not applied yet';
         }
         print "\n";
     }
     foreach my $orphan ( @{$status->{plan_orphans}} ){
-        print "ORPHANED: '".$orphan."'   Gone from plan?!?\n";
+        print "\n    ".$colorizer->colored('⚠︎', "bold red")." Orphaned: '".$orphan."'   Gone from plan?!?\n";
     }
 }
 
